saveToMemory property
bool
get
saveToMemory
Returns whether file contents should be cached in memory after reading.
Implementation
bool get saveToMemory => _saveToMemory;
Returns whether file contents should be cached in memory after reading.
bool get saveToMemory => _saveToMemory;